import unittest
from goescalibration import instrument
import datetime
from netcdf import netcdf as nc
import os


class TestInstrument(unittest.TestCase):

    def setUp(self):
        with nc.loader('goes13.2014.124.123422.BAND_01.nc') as root:
            nc.getdim(root, 'xc', 200)
            nc.getdim(root, 'yc', 100)
            nc.getdim(root, 'time')
            nc.getvar(root, 'data', 'i4', ('time', 'yc', 'xc'), fill_value=1)

    def tearDown(self):
        os.system('rm *.nc')

    def test_calibration(self):
        params = instrument.calibration(datetime.datetime(2014, 11, 10),
                                        'goes13')
        self.assertEquals(params, {
            'space_measurement': 29.0,
            'postlaunch': 1.305,
            'counts_shift': 32.0,
            'prelaunch': [0.6118, 0.00116]})
        params = instrument.calibration(datetime.datetime(2014, 11, 11),
                                        'goes13')
        self.assertEquals(params, {
            'space_measurement': 29.0,
            'postlaunch': 1.308,
            'counts_shift': 32.0,
            'prelaunch': [0.6118, 0.00116]})

    def test_calibration_to(self):
        params = instrument.calibration_to(
            'data/goes13.2014.124.123422.BAND_01.nc')
        self.assertEquals(params, {
            'space_measurement': 29.0,
            'postlaunch': 1.293,
            'counts_shift': 32.0,
            'prelaunch': [0.6118, 0.00116]})

    def test_calibrate(self):
        instrument.calibrate('goes13.2014.124.123422.BAND_01.nc')
        with nc.loader('goes13.2014.124.123422.BAND_01.nc') as root:
            var = lambda v: float(nc.getvar(root, v)[0])
            self.assertAlmostEquals(var('space_measurement'), 29.0)
            self.assertAlmostEquals(var('postlaunch'), 1.293)
            self.assertAlmostEquals(var('counts_shift'), 32.0)
            # 0: radiance, 1: albedo
            self.assertAlmostEquals(var('prelaunch_0'), 0.6118)
            self.assertAlmostEquals(var('prelaunch_1'), 0.00116)

    def test_load_calibration_using_netcdf_package(self):
        instrument.calibrate('goes13.2014.124.123422.BAND_01.nc')
        array_g = lambda x: [x for i in range(5)]
        with nc.loader(array_g('goes13.2014.124.123422.BAND_01.nc')) as root:
            var = lambda v: map(float, nc.getvar(root, v)[:])
            for i in range(5):
                self.assertAlmostEquals(var('space_measurement')[i],
                                        array_g(29.0)[i])
                self.assertAlmostEquals(var('postlaunch')[i],
                                        array_g(1.293)[i])
                self.assertAlmostEquals(var('counts_shift')[i],
                                        array_g(32.0)[i])
                # 0: radiance, 1: albedo
                self.assertAlmostEquals(var('prelaunch_0')[i],
                                        array_g(0.6118)[i])
                self.assertAlmostEquals(var('prelaunch_1')[i],
                                        array_g(0.00116)[i])


if __name__ == '__main__':
    unittest.main()
